import "core-js/modules/es6.regexp.match";
import "core-js/modules/es6.regexp.split";
import "core-js/modules/es6.regexp.replace";
import _typeof from "@babel/runtime/helpers/typeof";
import "core-js/modules/es6.regexp.to-string";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.number.constructor";
import cn from 'classnames';
export function clone(item) {
  if (!item) return item;
  var types = [Number, String, Boolean],
      result;
  types.forEach(function (type) {
    if (item instanceof type) {
      result = type(item);
    }
  });

  if (typeof result == "undefined") {
    if (Object.prototype.toString.call(item) === "[object Array]") {
      result = [];
      item.forEach(function (child, index, array) {
        result[index] = clone(child);
      });
    } else if (_typeof(item) == "object") {
      if (item.nodeType && typeof item.cloneNode == "function") {
        var result = item.cloneNode(true);
      } else if (!item.prototype) {
        if (item instanceof Date) {
          result = new Date(item);
        } else {
          result = {};

          for (var i in item) {
            result[i] = clone(item[i]);
          }
        }
      } else {
        if (false && item.constructor) {
          result = new item.constructor();
        } else {
          result = item;
        }
      }
    } else {
      result = item;
    }
  }

  return result;
}
export function renderTitle(status, data) {
  var uploading = 2;
  var uploaded = 3;
  var classNames = {
    'tool-img': status == uploading || status == uploaded,
    'in-uploade-circle': status == uploading,
    'uploade-success': status == uploaded
  };
  return React.createElement("div", null, React.createElement("span", {
    className: cn(classNames)
  }), React.createElement("label", null, data[status]));
}
export function getValue(color) {
  //获得16进制 a-f 的 十进制值
  var mapLetters = {
    'a': 10,
    'A': 10,
    'b': 11,
    'B': 11,
    'c': 12,
    'C': 12,
    'd': 13,
    'D': 13,
    'e': 14,
    'E': 14,
    'f': 15,
    'F': 15
  };
  var result;

  for (var i in mapLetters) {
    if (i == color) {
      result = mapLetters[i];
    }
  }

  return result;
}
export function convertColor(color, opacity) {
  //16进制颜色转换rgba格式
  var value = color.slice(1);
  var r = 0,
      g = 0,
      b = 0;

  for (var i in value) {
    if (!i) return;
    var val = isNaN(parseInt(value[i])) ? getValue(value[i]) : parseInt(value[i]);

    switch (parseInt(i)) {
      case 0:
        r = val * 16;
        break;

      case 1:
        r += val;
        break;

      case 2:
        g = val * 16;
        break;

      case 3:
        g += val;
        break;

      case 4:
        b = val * 16;
        break;

      case 5:
        b += val;
        break;

      default:
        break;
    }
  }

  return "rgba(".concat(r, ",").concat(g, ",").concat(b, ",").concat(opacity, ")");
}
export function htmlDecode(s) {
  //html解码
  if (s.length == 0) return "";
  s = s.replace(/&gt;/g, ">");
  s = s.replace(/&lt;/g, "<");
  s = s.replace(/&amp;/g, "&");
  s = s.replace(/&nbsp;/g, " ");
  s = s.replace(/&#39;/g, "\'");
  s = s.replace(/&quot;/g, "\"");
  s = s.replace(/<br>/g, "\n");
  return s;
}
export function fixHTML(text) {
  //删除所有HTML标签;
  text = text.replace(/<\/?.+?>/g, "");
  text.replace(/&nbsp;/g, "");
  return text;
}
export function changeText(val, style) {
  if (!val || val == '-') return '-';

  switch (style) {
    case 0:
      //数字
      var temp = val.split('/')[0];
      return temp;

    case 2:
      //百分比
      var float1 = parseFloat(eval(val) * 100);
      return isNaN(float1) ? '-' : float1.toFixed(0) + '%';

    case 3:
      //小数
      var float2 = parseFloat(eval(val));
      return isNaN(float2) ? '-' : float2.toFixed(2);

    default:
      //分数
      return val;
  }
}
export function uploadImg(url, formData, funcName, funcLoading, funcFail) {
  // url:上传接口
  // formData:图片的formData
  // funcName:回调函数名字，绑在window上的方法，
  formData.append('jsCallback', funcName);
  var xhr = new XMLHttpRequest();

  xhr.onreadystatechange = function (event) {
    if (xhr.readyState == 2) {
      funcLoading && funcLoading();
    }

    if (xhr.readyState == 4) {
      if (xhr.status == 200) {
        var text = xhr.responseText || xhr.response;
        text = text.replace(/<[^>]*>/g, '');

        try {
          eval(text);
        } catch (error) {
          funcFail && funcFail();
        }
      }
    }
  };

  xhr.open('POST', url, true);
  xhr.send(formData);
}
export function fixDomParent(dom, style) {
  var node = dom.parentNode;
  var i = 5; //限制5层，去padding

  while (node.className != 'ui-b-v-proxy' && i > 0) {
    node = node.parentNode;
    i--;
  }

  node.style.paddingLeft = style.paddingLeft;
  node.style.paddingRight = style.paddingRight;
  node.style.marginLeft = style.marginLeft;
  node.style.marginRight = style.marginRight;
  node.style.width = "calc( 100% - 20px )";
}
export function substring(str, len, hasDot) {
  if (!str) {
    return "";
  }

  var newLength = 0;
  var newStr = "";
  var chineseRegex = /[^\x00-\xff]/g;
  var singleChar = "";
  var strLength = str.replace(chineseRegex, "**").length;

  for (var i = 0; i < strLength; i++) {
    singleChar = str.charAt(i).toString();

    if (singleChar.match(chineseRegex) != null) {
      newLength += 2;
    } else {
      newLength++;
    }

    if (newLength > len) {
      break;
    }

    newStr += singleChar;
  }

  if (hasDot && strLength > len) {
    newStr += "...";
  }

  return newStr;
}